@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
- * Copyright (c) 2015-2024 Google, Inc.
+ * Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
+ * Copyright (c) 2015-2025 Google, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,10 +13,11 @@
 
 #include "../framework/layer_validation_tests.h"
 #include "../framework/android_hardware_buffer.h"
-#include "generated/vk_extension_helper.h"
 
 #if defined(VK_USE_PLATFORM_ANDROID_KHR)
 
+class PositiveAndroidHardwareBuffer : public VkLayerTest {};
+
 TEST_F(PositiveAndroidHardwareBuffer, MemoryRequirements) {
     TEST_DESCRIPTION("Verify AndroidHardwareBuffer doesn't conflict with memory requirements.");
 
@@ -28,7 +29,10 @@ TEST_F(PositiveAndroidHardwareBuffer, MemoryRequirements) {
     VkExternalMemoryBufferCreateInfo ext_buf_info = vku::InitStructHelper();
     ext_buf_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROID;
 
-    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+
+    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper(&memory_dedicated_info);
     import_ahb_Info.buffer = ahb.handle();
 
     VkAndroidHardwareBufferPropertiesANDROID ahb_props = vku::InitStructHelper();
@@ -43,10 +47,11 @@ TEST_F(PositiveAndroidHardwareBuffer, MemoryRequirements) {
     buffer_create_info.size = memory_allocate_info.allocationSize;
     buffer_create_info.usage = VK_BUFFER_USAGE_UNIFORM_BUFFER_BIT;
     vkt::Buffer buffer(*m_device, buffer_create_info, vkt::no_mem);
+    memory_dedicated_info.buffer = buffer;
 
     // Should be able to bind memory with no error
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
-    vk::BindBufferMemory(device(), buffer.handle(), memory, 0);
+    vk::BindBufferMemory(device(), buffer, memory, 0);
 }
 
 TEST_F(PositiveAndroidHardwareBuffer, DepthStencil) {
@@ -93,7 +98,7 @@ TEST_F(PositiveAndroidHardwareBuffer, DepthStencil) {
     }
 
     VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
-    memory_dedicated_info.image = ds_image.handle();
+    memory_dedicated_info.image = ds_image;
     memory_dedicated_info.buffer = VK_NULL_HANDLE;
 
     VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info =
@@ -106,7 +111,7 @@ TEST_F(PositiveAndroidHardwareBuffer, DepthStencil) {
     }
 
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
-    vk::BindImageMemory(device(), ds_image.handle(), memory, 0);
+    vk::BindImageMemory(device(), ds_image, memory, 0);
 }
 
 TEST_F(PositiveAndroidHardwareBuffer, BindBufferMemory) {
@@ -126,11 +131,11 @@ TEST_F(PositiveAndroidHardwareBuffer, BindBufferMemory) {
 
     // Try to get memory requirements prior to binding memory
     VkMemoryRequirements mem_reqs;
-    vk::GetBufferMemoryRequirements(device(), buffer.handle(), &mem_reqs);
+    vk::GetBufferMemoryRequirements(device(), buffer, &mem_reqs);
 
     // Test bind memory 2 extension
     VkBufferMemoryRequirementsInfo2 buffer_mem_reqs2 = vku::InitStructHelper();
-    buffer_mem_reqs2.buffer = buffer.handle();
+    buffer_mem_reqs2.buffer = buffer;
     VkMemoryRequirements2 mem_reqs2 = vku::InitStructHelper();
     vk::GetBufferMemoryRequirements2(device(), &buffer_mem_reqs2, &mem_reqs2);
 
@@ -141,7 +146,11 @@ TEST_F(PositiveAndroidHardwareBuffer, BindBufferMemory) {
     VkAndroidHardwareBufferPropertiesANDROID ahb_props = vku::InitStructHelper();
     vk::GetAndroidHardwareBufferPropertiesANDROID(device(), ahb.handle(), &ahb_props);
 
-    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+    memory_dedicated_info.buffer = buffer;
+
+    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper(&memory_dedicated_info);
     import_ahb_Info.buffer = ahb.handle();
 
     VkMemoryAllocateInfo memory_allocate_info = vku::InitStructHelper(&import_ahb_Info);
@@ -150,7 +159,7 @@ TEST_F(PositiveAndroidHardwareBuffer, BindBufferMemory) {
     }
 
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
-    vk::BindBufferMemory(device(), buffer.handle(), memory, 0);
+    vk::BindBufferMemory(device(), buffer, memory, 0);
 }
 
 TEST_F(PositiveAndroidHardwareBuffer, ExportBuffer) {
@@ -170,21 +179,26 @@ TEST_F(PositiveAndroidHardwareBuffer, ExportBuffer) {
     vkt::Buffer buffer(*m_device, buffer_create_info, vkt::no_mem);
 
     VkMemoryRequirements mem_reqs;
-    vk::GetBufferMemoryRequirements(device(), buffer.handle(), &mem_reqs);
+    vk::GetBufferMemoryRequirements(device(), buffer, &mem_reqs);
 
-    VkExportMemoryAllocateInfo export_memory_info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+    memory_dedicated_info.buffer = buffer;
+
+    VkExportMemoryAllocateInfo export_memory_info = vku::InitStructHelper(&memory_dedicated_info);
     export_memory_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROID;
 
     VkMemoryAllocateInfo memory_info = vku::InitStructHelper(&export_memory_info);
     memory_info.allocationSize = mem_reqs.size;
 
-    bool has_memtype = m_device->phy().set_memory_type(mem_reqs.memoryTypeBits, &memory_info, VK_MEMORY_PROPERTY_DEVICE_LOCAL_BIT);
+    bool has_memtype =
+        m_device->Physical().SetMemoryType(mem_reqs.memoryTypeBits, &memory_info, VK_MEMORY_PROPERTY_DEVICE_LOCAL_BIT);
     if (!has_memtype) {
         GTEST_SKIP() << "No valid memory type index could be found";
     }
 
     vkt::DeviceMemory memory(*m_device, memory_info);
-    vk::BindBufferMemory(device(), buffer.handle(), memory, 0);
+    vk::BindBufferMemory(device(), buffer, memory, 0);
 
     // Export memory to AHB
     AHardwareBuffer *ahb = nullptr;
@@ -223,7 +237,7 @@ TEST_F(PositiveAndroidHardwareBuffer, ExportImage) {
     vkt::Image image(*m_device, image_create_info, vkt::no_mem);
 
     VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
-    memory_dedicated_info.image = image.handle();
+    memory_dedicated_info.image = image;
     memory_dedicated_info.buffer = VK_NULL_HANDLE;
 
     VkExportMemoryAllocateInfo export_memory_info = vku::InitStructHelper(&memory_dedicated_info);
@@ -236,13 +250,13 @@ TEST_F(PositiveAndroidHardwareBuffer, ExportImage) {
     memory_info.allocationSize = 0;
 
     // Use any DEVICE_LOCAL memory found
-    bool has_memtype = m_device->phy().set_memory_type(0xFFFFFFFF, &memory_info, VK_MEMORY_PROPERTY_DEVICE_LOCAL_BIT);
+    bool has_memtype = m_device->Physical().SetMemoryType(0xFFFFFFFF, &memory_info, VK_MEMORY_PROPERTY_DEVICE_LOCAL_BIT);
     if (!has_memtype) {
         GTEST_SKIP() << "No valid memory type index could be found";
     }
 
     vkt::DeviceMemory memory(*m_device, memory_info);
-    vk::BindImageMemory(device(), image.handle(), memory, 0);
+    vk::BindImageMemory(device(), image, memory, 0);
 
     // Export memory to AHB
     AHardwareBuffer *ahb = nullptr;
@@ -301,7 +315,7 @@ TEST_F(PositiveAndroidHardwareBuffer, ExternalImage) {
     vkt::Image image(*m_device, image_create_info, vkt::no_mem);
 
     VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
-    memory_dedicated_info.image = image.handle();
+    memory_dedicated_info.image = image;
     memory_dedicated_info.buffer = VK_NULL_HANDLE;
 
     VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info =
@@ -314,7 +328,7 @@ TEST_F(PositiveAndroidHardwareBuffer, ExternalImage) {
     }
 
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
-    vk::BindImageMemory(device(), image.handle(), memory, 0);
+    vk::BindImageMemory(device(), image, memory, 0);
 }
 
 TEST_F(PositiveAndroidHardwareBuffer, ExternalCameraFormat) {
@@ -370,7 +384,7 @@ TEST_F(PositiveAndroidHardwareBuffer, ExternalCameraFormat) {
     vkt::Image image(*m_device, image_create_info, vkt::no_mem);
 
     VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
-    memory_dedicated_info.image = image.handle();
+    memory_dedicated_info.image = image;
     memory_dedicated_info.buffer = VK_NULL_HANDLE;
 
     VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info =
@@ -383,7 +397,7 @@ TEST_F(PositiveAndroidHardwareBuffer, ExternalCameraFormat) {
     }
 
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
-    vk::BindImageMemory(device(), image.handle(), memory, 0);
+    vk::BindImageMemory(device(), image, memory, 0);
 }
 
 TEST_F(PositiveAndroidHardwareBuffer, DeviceImageMemoryReq) {
